@@ -61,12 +61,16 @@ class APIHandler(object):
         self.profiler_min_duration = profiler_min_duration
         self.global_timeout = global_timeout
 
-    def get_session(self):
+    def get_session(self, retry_total=None, retry_backoff_factor=None):
         session = requests.Session()
-        if self.retry_config:
+        if retry_total is None:
+            retry_total = self.retry_config.get('total')
+        if retry_backoff_factor is None:
+            retry_backoff_factor = self.retry_config.get('backoff_factor')
+        if retry_total is not None or retry_backoff_factor is not None:
             retry = Retry(
-                total=self.retry_config.get('total', 3),
-                backoff_factor=self.retry_config.get('backoff_factor', 1),
+                total=retry_total or 1,
+                backoff_factor=retry_backoff_factor or 1,
                 status_forcelist=self.retry_config.get('status_forcelist', (500, 502, 504))
             )
             adapter = HTTPAdapter(
@@ -122,7 +126,39 @@ class APIHandler(object):
         instance = cls(url=url)
         return instance.call(no_auth=True, *args, **kwargs)
 
-    def call(self, method, path, data=None, params=None, no_auth=False, raw=False, timeout=None):
+    def call(
+            self,
+            method,
+            path,
+            data=None,
+            params=None,
+            no_auth=False,
+            raw=False,
+            timeout=None,
+            retry_total=None,
+            retry_backoff_factor=None,
+            ):
+        """Performs the API request handling authorization and the status codes errors.
+        Returns the response content as a dictionary or text if argument raw=True.
+
+        Args:
+            method (str): Http methods allowed are GET, PUT, POST, DELETE or OPTIONS.
+            path (str): URL path. Could start either with / or without it. Eg: '/accounts/A1234'
+            data (dict/list): Object to be passed in the body when the method is one of PUT or POST.
+            params (dict): Query params of the request.
+            no_auth (bool): False by default. If True, authorization headers with mc_token and mc_secret won't be sent.
+            raw (bool): False by default. If True, will return the raw text of the response instead of trying to parse
+                it from JSON. This is needed when working with CSV endpoints.
+            timeout (float/tuple): requests module timeout parameter. Timeouts can be for connecting or for reading. If
+                a tuple is sent, the first value will be the timeout for connections and the second for reads, otherwise
+                will use the same value for both.
+            retry_total (int): Number of times it will retry the request if it timeouts or if an 5xx error is raised.
+                If not present, will use the values from the retry_config argument passed when creating the APIHandler
+                instance.
+            retry_backoff_factor (float): Backoff factor for waiting before retrying the request.
+                If not present, will use the values from the retry_config argument passed when creating the APIHandler
+                instance.
+        """
         if method.upper() not in ['GET', 'PUT', 'POST', 'DELETE', 'OPTIONS']:
             raise Exception("Invalid method ")
 
@@ -152,7 +188,7 @@ class APIHandler(object):
 
         url = self.url.strip("/") + "/" + path.strip("/")
 
-        with self.get_session() as session:
+        with self.get_session(retry_total=retry_total, retry_backoff_factor=retry_backoff_factor) as session:
             func = getattr(session, method.lower())
             try:
                 response = func(url, **request_kwargs)
