@@ -29,5 +29,8 @@ class User(Entity):
         return self._data.get("role")
 
     @property
-    def accounts(self):
-        return [Account(account_id, None, api=self.api) for account_id in self._data["accounts"]]
+    def accounts(self, **kwargs):
+        return [
+            Account(account_id, None, api=self.api, **kwargs)
+            for account_id in self._data["accounts"]
+        ]
