@@ -27,12 +27,13 @@ class Zone(Entity):
             return []
         return [Zone(data['id'], data, api=self.api) for data in self._data.get("sub_zones", [])]
 
-    def get_alerts(self, attributes=None, params=None):
+    def get_alerts(self, attributes=None, params=None, api_call_kwargs={}):
         """:obj:`list` of :obj:`Alert`: Fetch a list of alerts for the zone, according to the used params
 
         Args:
             attributes (list): Optional list of attributes to request.
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         alerts = get_alerts(
             self.api,
@@ -40,5 +41,6 @@ class Zone(Entity):
             zone_id=self._id,
             attributes=attributes,
             params=params,
+            api_call_kwargs=api_call_kwargs,
         )
         return alerts
